==> jc-1.4.0.tar.gz: javax/swing/Box__24Filler__24AccessibleBoxFiller.h <==
// public class javax.swing.Box$Filler$AccessibleBoxFiller

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8cbec6b4bd9e30b1 javax_swing_Box__24Filler__24AccessibleBoxFiller

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_
#define _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_Box__24Filler$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object;

typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *, struct _jc_javax_swing_Box__24Filler$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *);
};

// Vtable
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods	javax_swing_Box__24Filler__24AccessibleBoxFiller;
};

// Vtype
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs {
	struct _jc_javax_swing_Box__24Filler$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs {
    _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs	javax_swing_Box__24Filler__24AccessibleBoxFiller;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs	javax_swing_Box__24Filler__24AccessibleBoxFiller;
};

// Object instance structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object {
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype	*vtype;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24Filler__24AccessibleBoxFiller, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_object;

#endif	/* _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Box__24Filler__24AccessibleBoxFiller.h <==
// public class javax.swing.Box$Filler$AccessibleBoxFiller

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8cbec6b4bd9e30b1 javax_swing_Box__24Filler__24AccessibleBoxFiller

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_
#define _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_Box__24Filler$object;

// Typedefs
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs;
typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object;

typedef struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable;
typedef const struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype;

// Class fields structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$fields_struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_fields;

// Constructors
extern void _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$_init$c3ce195336b3e4d6(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *, struct _jc_javax_swing_Box__24Filler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vmethods	javax_swing_Box__24Filler__24AccessibleBoxFiller;
};

// Vtype
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype {
	_jc_type			type;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs {
	struct _jc_javax_swing_Box__24Filler$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs {
    _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_refs	javax_swing_Box__24Filler__24AccessibleBoxFiller;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$sub_nonrefs	javax_swing_Box__24Filler__24AccessibleBoxFiller;
};

// Object instance structure
struct _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$object {
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype	*vtype;
	_jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$vtype _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Box__24Filler__24AccessibleBoxFiller, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Box__24Filler__24AccessibleBoxFiller$class_object;

#endif	/* _JC_javax_swing_Box__24Filler__24AccessibleBoxFiller_H_ */
